// Version information for the "BasicUsageEnvironment" library
// Copyright (c) 1996-2009 Live Networks, Inc.  All rights reserved.

#ifndef _BASICUSAGEENVIRONMENT_VERSION_HH
#define _BASICUSAGEENVIRONMENT_VERSION_HH

#define BASICUSAGEENVIRONMENT_LIBRARY_VERSION_STRING	"2009.11.27"
#define BASICUSAGEENVIRONMENT_LIBRARY_VERSION_INT		1259280000

#endif
